@@ -1,3 +1,22 @@
+/* Bluefish HTML Editor
+ * bfspell.c - aspell spell checker
+ *
+ * Copyright (C) 2002-2004 Olivier Sessink
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
 /* #define DEBUG */
 
 #include "config.h"
@@ -6,6 +25,7 @@
 #include <aspell.h>
 #include <gtk/gtk.h>
 #include <string.h>
+#include <ctype.h> /* isdigit() */
 
 #include "bluefish.h"
 #include "gtk_easy.h"
@@ -42,6 +62,13 @@ typedef struct {
 	Tbfwin *bfwin;
 } Tbfspell;
 
+static void spell_gui_set_button_status(Tbfspell *bfspell, gboolean is_running) {
+	gtk_widget_set_sensitive(bfspell->runbut,!is_running);
+	gtk_widget_set_sensitive(bfspell->lang,!is_running);
+	gtk_widget_set_sensitive(bfspell->repbut,is_running);
+	gtk_widget_set_sensitive(bfspell->ignbut,is_running);
+}
+
 static gboolean test_unichar(gunichar ch,gpointer data) {
 	if (ch == GPOINTER_TO_INT(data)) {
 		return TRUE;
@@ -99,59 +126,66 @@ void spell_add_to_session(Tbfspell *bfspell, gboolean to_session, const gchar *
 }
 
 gboolean spell_check_word(Tbfspell *bfspell, gchar * tocheck, GtkTextIter *itstart, GtkTextIter *itend) {
-	int correct = aspell_speller_check(bfspell->spell_checker, tocheck, -1);
-	DEBUG_MSG("word '%s' has correct=%d\n",tocheck,correct);
-	if (!correct) {
-		AspellWordList *awl = (AspellWordList *)aspell_speller_suggest(bfspell->spell_checker, tocheck,-1);
-		if (!bfspell->so || !bfspell->eo) {
-			bfspell->so = gtk_text_buffer_create_mark(bfspell->doc->buffer,NULL,itstart,FALSE);
-			bfspell->eo = gtk_text_buffer_create_mark(bfspell->doc->buffer,NULL,itend,TRUE);
-		} else {
-			gtk_text_buffer_move_mark(bfspell->doc->buffer,bfspell->so,itstart);
-			gtk_text_buffer_move_mark(bfspell->doc->buffer,bfspell->eo,itend);
-		}
-		doc_select_region(bfspell->doc, gtk_text_iter_get_offset(itstart),gtk_text_iter_get_offset(itend) , TRUE);
-		bfspell->offset = -1;
-		gtk_entry_set_text(GTK_ENTRY(bfspell->incorrectword), tocheck);
-		gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(bfspell->suggestions)->entry), "");
-		if (awl == 0) {
-			DEBUG_MSG("spell_check_word error: %s\n", aspell_speller_error_message(bfspell->spell_checker));
-		} else {
-			GList *poplist=NULL;
-			AspellStringEnumeration *els = aspell_word_list_elements(awl);
-			const char *word;
-			while ((word = aspell_string_enumeration_next(els)) != 0) {
-				poplist = g_list_append(poplist,g_strdup(word));
-			}
-			if (!poplist) {
-				poplist = g_list_append(poplist, g_strdup("(no suggested words)"));
+	if (tocheck && !isdigit(tocheck[0])) {
+		int correct = aspell_speller_check(bfspell->spell_checker, tocheck, -1);
+		DEBUG_MSG("word '%s' has correct=%d\n",tocheck,correct);
+		if (!correct) {
+			AspellWordList *awl = (AspellWordList *)aspell_speller_suggest(bfspell->spell_checker, tocheck,-1);
+			if (!bfspell->so || !bfspell->eo) {
+				bfspell->so = gtk_text_buffer_create_mark(bfspell->doc->buffer,NULL,itstart,FALSE);
+				bfspell->eo = gtk_text_buffer_create_mark(bfspell->doc->buffer,NULL,itend,TRUE);
+			} else {
+				gtk_text_buffer_move_mark(bfspell->doc->buffer,bfspell->so,itstart);
+				gtk_text_buffer_move_mark(bfspell->doc->buffer,bfspell->eo,itend);
 			}
+			doc_select_region(bfspell->doc, gtk_text_iter_get_offset(itstart),gtk_text_iter_get_offset(itend) , TRUE);
+			bfspell->offset = -1;
+			gtk_entry_set_text(GTK_ENTRY(bfspell->incorrectword), tocheck);
 			gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(bfspell->suggestions)->entry), "");
-			gtk_combo_set_popdown_strings(GTK_COMBO(bfspell->suggestions), poplist);
-			free_stringlist(poplist);
-			delete_aspell_string_enumeration(els);
+			if (awl == 0) {
+				DEBUG_MSG("spell_check_word error: %s\n", aspell_speller_error_message(bfspell->spell_checker));
+			} else {
+				GList *poplist=NULL;
+				AspellStringEnumeration *els = aspell_word_list_elements(awl);
+				const char *word;
+				while ((word = aspell_string_enumeration_next(els)) != 0) {
+					poplist = g_list_append(poplist,g_strdup(word));
+				}
+				if (!poplist) {
+					poplist = g_list_append(poplist, g_strdup("(no suggested words)"));
+				}
+				gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(bfspell->suggestions)->entry), "");
+				gtk_combo_set_popdown_strings(GTK_COMBO(bfspell->suggestions), poplist);
+				free_stringlist(poplist);
+				delete_aspell_string_enumeration(els);
+			}
+			return FALSE;
 		}
-		return FALSE;
-	} else {
-		return TRUE;
 	}
+	return TRUE;
+}
+
+static void spell_run_finished(Tbfspell *bfspell) {
+	GList *poplist = NULL;
+	DEBUG_MSG("spell_run_finished\n");
+	gtk_entry_set_text(GTK_ENTRY(bfspell->incorrectword), "");
+	gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(bfspell->suggestions)->entry), "");
+	poplist = g_list_append(poplist,"");
+	gtk_combo_set_popdown_strings(GTK_COMBO(bfspell->suggestions), poplist);
+	g_list_free(poplist);
+	bfspell->offset = 0;
+	aspell_speller_save_all_word_lists(bfspell->spell_checker);
+	delete_aspell_speller(bfspell->spell_checker);
+	bfspell->spell_checker = NULL;
+	spell_gui_set_button_status(bfspell, FALSE);
 }
 
 gboolean spell_run(Tbfspell *bfspell) {
 	GtkTextIter itstart,itend;
 	gchar *word = doc_get_next_word(bfspell, &itstart,&itend);
+	DEBUG_MSG("spell_run, started, bfspell=%p, word=%s\n",bfspell,word);
 	if (!word) {
-		GList *poplist = NULL;
-		DEBUG_MSG("spell_run: finished\n");
-		gtk_entry_set_text(GTK_ENTRY(bfspell->incorrectword), "");
-		gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(bfspell->suggestions)->entry), "");
-		poplist = g_list_append(poplist,"");
-		gtk_combo_set_popdown_strings(GTK_COMBO(bfspell->suggestions), poplist);
-		g_list_free(poplist);
-		bfspell->offset = 0;
-		aspell_speller_save_all_word_lists(bfspell->spell_checker);
-		delete_aspell_speller(bfspell->spell_checker);
-		bfspell->spell_checker = NULL;
+		spell_run_finished(bfspell);
 		return FALSE; /* finished */
 	}
 	while (word) {
@@ -159,7 +193,11 @@ gboolean spell_run(Tbfspell *bfspell) {
 		if (spell_check_word(bfspell,word,&itstart,&itend)) {
 			g_free(word);
 			word = doc_get_next_word(bfspell,&itstart,&itend);
-		} else {
+			if (!word) {
+				spell_run_finished(bfspell);
+				return FALSE; /* finished */
+			}
+		} else { /* not correct ! */
 			g_free(word);
 			word = NULL;
 		}
@@ -167,13 +205,16 @@ gboolean spell_run(Tbfspell *bfspell) {
 	return TRUE; /* not yet finished */
 }
 
-void spell_start(Tbfspell *bfspell) {	
+void spell_start(Tbfspell *bfspell) {
+	DEBUG_MSG("spell_start, started for bfspell=%p\n",bfspell);
 	bfspell->spell_config = new_aspell_config();
+	DEBUG_MSG("spell_start, created spell_config at %p\n",bfspell->spell_config);
 	/*
 	 * default language should come from config file, runtime from GUI,
 	 * should first set the default one 
 	 */
 	aspell_config_replace(bfspell->spell_config, "lang", main_v->props.spell_default_lang);
+	DEBUG_MSG("spell_start, default lang=%s\n",main_v->props.spell_default_lang);
 	/*
 	 * it is unclear from the manual if aspell supports utf-8 in the
 	 * library, the utility does not support it.. 
@@ -205,25 +246,20 @@ void spell_gui_cancel_clicked_cb(GtkWidget *widget, Tbfspell *bfspell) {
 	spell_gui_destroy(NULL, bfspell);
 }
 
-static void spell_gui_set_button_status(Tbfspell *bfspell, gboolean is_running) {
-	gtk_widget_set_sensitive(bfspell->runbut,!is_running);
-	gtk_widget_set_sensitive(bfspell->lang,!is_running);
-	gtk_widget_set_sensitive(bfspell->repbut,is_running);
-	gtk_widget_set_sensitive(bfspell->ignbut,is_running);
-}
-
 void spell_gui_ok_clicked_cb(GtkWidget *widget, Tbfspell *bfspell) {
 	AspellCanHaveError *possible_err;
 	const gchar *lang;
+	DEBUG_MSG("spell_gui_ok_clicked_cb, bfspell=%p, bfwin=%p\n",bfspell, bfspell->bfwin);
 	bfspell->doc = bfspell->bfwin->current_document;
 	{
 		gint indx;
 		indx = gtk_option_menu_get_history(GTK_OPTION_MENU(bfspell->lang));
 		lang = g_list_nth_data(bfspell->langs, indx);
+		DEBUG_MSG("spell_gui_ok_clicked_cb, indx=%d has language %s\n",indx,lang);
 	}
 	aspell_config_replace(bfspell->spell_config, "lang", lang);
-	DEBUG_MSG("spell_gui_ok_clicked_cb, set lang to %s\n",lang);
 
+	DEBUG_MSG("spell_gui_ok_clicked_cb, about to create speller for spell_config=%p\n",bfspell->spell_config);
 	possible_err = new_aspell_speller(bfspell->spell_config);
 	bfspell->spell_checker = 0;
 	if (aspell_error_number(possible_err) != 0) {
@@ -242,7 +278,7 @@ void spell_gui_ok_clicked_cb(GtkWidget *widget, Tbfspell *bfspell) {
 		bfspell->offset = gtk_text_iter_get_offset(&start);
 		bfspell->stop_position = gtk_text_iter_get_offset(&end);
 	}
-
+	DEBUG_MSG("about to start spell_run()\n");
 	if (spell_run(bfspell)) {
 		spell_gui_set_button_status(bfspell,TRUE);
 	} else {
@@ -266,20 +302,23 @@ void spell_gui_fill_dicts(Tbfspell *bfspell) {
 		GtkWidget *label;
 		menuitem = gtk_menu_item_new();
 		label = gtk_label_new(entry->name);
-		bfspell->langs = g_list_append(bfspell->langs,g_strdup(entry->name));
 		gtk_misc_set_alignment(GTK_MISC(label),0,0.5);
 		gtk_container_add(GTK_CONTAINER(menuitem), label);
-		DEBUG_MSG("adding language %s to menuitem %p using label %p\n",entry->name,menuitem,label);
 /*		g_signal_connect(G_OBJECT (menuitem), "activate",G_CALLBACK(),GINT_TO_POINTER(0));*/
 		if (strcmp(entry->name, main_v->props.spell_default_lang) == 0) {
+			DEBUG_MSG("spell_gui_fill_dicts, lang %s is the default language, inserting menuitem %p at position 0\n",entry->name,menuitem);
 			gtk_menu_shell_insert(GTK_MENU_SHELL(menu), menuitem, 0);
+			bfspell->langs = g_list_prepend(bfspell->langs,g_strdup(entry->name));
 		} else {
+			DEBUG_MSG("spell_gui_fill_dicts, lang %s is not the default language, appending menuitem %p\n",entry->name,menuitem);
 			gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
+			bfspell->langs = g_list_append(bfspell->langs,g_strdup(entry->name));
 		}
 	}
 	delete_aspell_dict_info_enumeration(dels);
 	gtk_widget_show_all(menu);
 	gtk_option_menu_set_menu(GTK_OPTION_MENU(bfspell->lang), menu);
+	DEBUG_MSG("spell_gui_fill_dicts, set item 0 as selected item\n");
 	gtk_option_menu_set_history(GTK_OPTION_MENU(bfspell->lang),0);
 }
 
@@ -287,10 +326,15 @@ void spell_gui_add_clicked(GtkWidget *widget, Tbfspell *bfspell) {
 	const gchar *original = gtk_entry_get_text(GTK_ENTRY(bfspell->incorrectword));
 	if (strlen(original)) {
 		if (gtk_option_menu_get_history(GTK_OPTION_MENU(bfspell->dict))) {
-			spell_add_to_session(bfspell, FALSE,original);
-		} else {
 			spell_add_to_session(bfspell, TRUE,original);
+		} else {
+			spell_add_to_session(bfspell, FALSE,original);
 		}
+		}
+	if (spell_run(bfspell)) {
+		spell_gui_set_button_status(bfspell,TRUE);
+	} else {
+		spell_gui_set_button_status(bfspell,FALSE);
 	}
 }
 void spell_gui_ignore_clicked(GtkWidget *widget, Tbfspell *bfspell) {
@@ -328,7 +372,7 @@ static void defaultlang_clicked_lcb(GtkWidget *widget,Tbfspell *bfspell) {
 	indx = gtk_option_menu_get_history(GTK_OPTION_MENU(bfspell->lang));
 	lang = g_list_nth_data(bfspell->langs, indx);
 	g_free(main_v->props.spell_default_lang);
-	DEBUG_MSG("defaultlang_clicked_lcb, default lang is now %s\n",lang);
+	DEBUG_MSG("defaultlang_clicked_lcb, index=%d, default lang is now %s\n",indx, lang);
 	main_v->props.spell_default_lang = g_strdup(lang);
 }
 void filter_changed_lcb(GtkOptionMenu *optionmenu,Tbfspell *bfspell) {
