@@ -1,6 +1,6 @@
 /* Bluefish HTML Editor
  *
- * Copyright (C) 1999-2004 Olivier Sessink
+ * Copyright (C) 1999-2005 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
+
 /* #define DEBUG */
+
 #include <gtk/gtk.h>
 #include <stdlib.h> /* strtod() */
 #include <string.h> /* strlen() */
@@ -528,7 +530,7 @@ GtkWidget *boxed_optionmenu_with_value(const gchar *labeltext, gint curval, GtkW
  *
  * Return value: #GtkWidget* pointer to created window
  */
-GtkWidget *window_with_title(gchar * title, GtkWindowPosition position, gint borderwidth) {
+GtkWidget *window_with_title(const gchar * title, GtkWindowPosition position, gint borderwidth) {
 	GtkWidget *returnwidget;
 
 	returnwidget = gtk_window_new(GTK_WINDOW_TOPLEVEL);
@@ -584,7 +586,7 @@ static gboolean window_full_key_press_event_lcb(GtkWidget *widget,GdkEventKey *e
  *
  * Return value: #GtkWidget* pointer to created window
  */
-GtkWidget *window_full2(gchar * title, GtkWindowPosition position
+GtkWidget *window_full2(const gchar * title, GtkWindowPosition position
 			, gint borderwidth, GCallback close_func
 			, gpointer close_data
 			, gboolean delete_on_escape,
@@ -633,7 +635,8 @@ GtkWidget *textview_buffer_in_scrolwin(GtkWidget **textview, gint width, gint he
 	gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(*textview), wrapmode);
 	scrolwin = gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolwin), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrolwin), *textview);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolwin), GTK_SHADOW_IN);
+	gtk_container_add (GTK_CONTAINER (scrolwin), *textview);
 	gtk_widget_set_size_request(scrolwin, width, height);
 	if (contents) {
 		gtk_text_buffer_set_text(textbuf, contents, -1);
@@ -928,7 +931,7 @@ static gboolean dialog_key_press_event_lcb(GtkWidget *widget,GdkEventKey *event,
  * (strong && larger) message and an additional, more descriptive message.
  * It is not resizeable, has no title, placement is selected by the wm.
  */
-static void hig_dialog_backend (GtkDialog *dialog, gchar *primary, gchar *secondary, gchar *icon)
+void hig_dialog_backend (GtkDialog *dialog, gchar *primary, gchar *secondary, gchar *icon)
 {
 	GtkWidget *vbox, *hbox, *image, *label;
 	gchar *message;
@@ -989,7 +992,7 @@ gint multi_button_dialog_backend(GtkWidget *win, gchar *primary, gchar *secondar
 	GtkWidget *dialog;
 	int i, retval;
 
-	dialog = gtk_dialog_new_with_buttons (NULL, /* Note that no title is being set. */
+	dialog = gtk_dialog_new_with_buttons ("", /* Note that no title is being set. */
 												GTK_WINDOW(win),
 												GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 												*buttons, 0,
@@ -1350,6 +1353,9 @@ GtkWidget * file_chooser_dialog(Tbfwin *bfwin, gchar *title, GtkFileChooserActio
 			(action == GTK_FILE_CHOOSER_ACTION_SAVE) ? GTK_STOCK_SAVE : GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 			NULL);
 	gtk_dialog_set_default_response (GTK_DIALOG(dialog), GTK_RESPONSE_ACCEPT);
+	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER(dialog), localonly);
+	gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER(dialog), multiple);	
+	
 	if (set && strlen(set)) {
 		DEBUG_MSG("file_chooser_dialog, set=%s,localonly=%d\n",set,localonly);
 		if (localonly || strchr(set,':')==NULL) {
@@ -1370,8 +1376,7 @@ GtkWidget * file_chooser_dialog(Tbfwin *bfwin, gchar *title, GtkFileChooserActio
 #ifdef DEBUG
 	DEBUG_MSG("file_chooser_dialog, current_folder_uri=%s\n", gtk_file_chooser_get_current_folder_uri(GTK_FILE_CHOOSER(dialog)));
 #endif
-	gtk_file_chooser_set_local_only(GTK_FILE_CHOOSER(dialog),localonly);
-	gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(dialog), multiple);
+
 /*	if (bfwin) {
 		GList *tmplist;
 		/ *tmplist = g_list_first(bfwin->session->recent_dirs);* /
