@@ -1,6 +1,6 @@
 /* Bluefish HTML Editor
  *
- * Copyright (C) 1999-2004 Olivier Sessink
+ * Copyright (C) 1999-2005 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@ typedef enum { none, file, font } Textra_but;
 void flush_queue(void);
 gint widget_get_string_size(GtkWidget *widget, gchar *string);
 void widget_set_visible(GtkWidget *widget, gboolean visible);
+void hig_dialog_backend (GtkDialog *dialog, gchar *primary, gchar *secondary, gchar *icon);
 /* Single-button dialogs*/
 void single_button_dialog_backend(GtkWidget *win,gchar * primary, gchar * secondary, gchar * icon);
 void error_dialog(GtkWidget *win,gchar * primary, gchar * secondary);
@@ -63,11 +64,11 @@ GtkWidget *boxed_radiobut_with_value(gchar *labeltext, gint enabled, GtkRadioBut
 GtkWidget *spinbut_with_value(gchar *value, gfloat lower, gfloat upper, gfloat step_increment, gfloat page_increment);
 GtkWidget *optionmenu_with_value(gchar **options, gint curval);
 GtkWidget *boxed_optionmenu_with_value(const gchar *labeltext, gint curval, GtkWidget *box, gchar **options);
-GtkWidget *window_with_title(gchar * title, GtkWindowPosition position, gint borderwidth);
+GtkWidget *window_with_title(const gchar * title, GtkWindowPosition position, gint borderwidth);
 
 #define window_full(title,position,borderwidth,close_func,close_data,delete_on_escape) window_full2(title,position,borderwidth,close_func,close_data,delete_on_escape,NULL)
 
-GtkWidget *window_full2(gchar * title, GtkWindowPosition position, gint borderwidth, GCallback close_func,
+GtkWidget *window_full2(const gchar * title, GtkWindowPosition position, gint borderwidth, GCallback close_func,
 					   gpointer close_data, gboolean delete_on_escape, GtkWidget *transientforparent);
 
 GtkWidget *textview_buffer_in_scrolwin(GtkWidget **textview, gint width, gint height, const gchar *contents, GtkWrapMode wrapmode);
