@@ -1,7 +1,7 @@
 /* Bluefish HTML Editor
  * gui.c - the main GUI
  *
- * Copyright (C) 2002-2004 Olivier Sessink
+ * Copyright (C) 2002-2005 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* #define DEBUG */
+
+/* #define DEBUG*/
 
 #include <gtk/gtk.h>
 #include <time.h> /* nanosleep() */
@@ -50,6 +51,10 @@
 #include "bookmark.h"
 #include "project.h"
 
+#ifdef HAVE_ATLEAST_GTK_2_4
+#include "quickstart.h"
+#endif /* HAVE_ATLEAST_GTK_2_4 */
+
 #ifdef HAVE_LIBASPELL
 #include "bfspell.h"
 #endif /* HAVE_LIBASPELL */
@@ -152,7 +157,7 @@ void notebook_changed(Tbfwin *bfwin, gint newpage) {
 
 gboolean switch_to_document_by_index(Tbfwin *bfwin,gint index) {
 	if (index >= 0) {
-		gtk_notebook_set_page(GTK_NOTEBOOK(bfwin->notebook), (index));
+		gtk_notebook_set_current_page(GTK_NOTEBOOK(bfwin->notebook), (index));
 /*		notebook_changed();*/
 		return TRUE;
 	}
@@ -185,9 +190,9 @@ void gui_notebook_switch(Tbfwin *bfwin,guint action,GtkWidget *widget) {
 		break;
 		case 2: gtk_notebook_next_page(GTK_NOTEBOOK(bfwin->notebook));
 		break;
-		case 3: gtk_notebook_set_page(GTK_NOTEBOOK(bfwin->notebook), 0);
+		case 3: gtk_notebook_set_current_page(GTK_NOTEBOOK(bfwin->notebook), 0);
 		break;
-		case 4: gtk_notebook_set_page(GTK_NOTEBOOK(bfwin->notebook), -1);
+		case 4: gtk_notebook_set_current_page(GTK_NOTEBOOK(bfwin->notebook), -1);
 	}
 }
 
@@ -480,7 +485,11 @@ static void acronym_clicked_lcb(GtkWidget *widget, Tbfwin *bfwin) {
 }
 
 static void quickstart_clicked_lcb(GtkWidget *widget, Tbfwin *bfwin) {
+#ifdef HAVE_ATLEAST_GTK_2_4
+	quickstart_dialog_new(bfwin);
+#else
 	quickstart_dialog(bfwin,NULL);
+#endif
 }
 static void body_clicked_lcb(GtkWidget *widget, Tbfwin *bfwin) {
 	body_dialog(bfwin,NULL);
@@ -596,7 +605,7 @@ static Ttoolbaritem tbi[] = {
 	{"center", center_clicked_lcb,  28, N_("Center")},
 	{"rightjustify", rightjustify_clicked_lcb,  29, N_("Right Justify")},
 	{"comment", comment_clicked_lcb, 30 , N_("Comment")},
-	{"email...", email_clicked_lcb, 31, N_("E-Mail...")},
+	{"email...", email_clicked_lcb, 31, N_("E-mail...")},
 	{"font...",fontdialog_clicked_lcb , 32, N_("Font...")},
 	{"basefont...", basefont_clicked_lcb, 33, N_("Base Font Size...")},
 	{"", NULL, 0, NULL}, /* spacing */
@@ -976,7 +985,6 @@ void make_html_toolbar(Tbfwin *bfwin) {
 	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(html_notebook), GTK_POS_TOP);
 	gtk_notebook_set_show_tabs(GTK_NOTEBOOK(html_notebook), TRUE);
 	gtk_notebook_set_show_border(GTK_NOTEBOOK(html_notebook), TRUE);
-	gtk_notebook_set_page(GTK_NOTEBOOK(html_notebook), 0);
 	gtk_container_add(GTK_CONTAINER(bfwin->html_toolbar_hb), html_notebook);
 
 	bfwin->toolbar_quickbar = gtk_toolbar_new();
@@ -1046,6 +1054,10 @@ void make_html_toolbar(Tbfwin *bfwin) {
 	gtk_notebook_append_page(GTK_NOTEBOOK(html_notebook), html_toolbar, gtk_label_new(_(" CSS ")));
 
 	gtk_widget_show_all(html_notebook);
+	
+	if (main_v->globses.quickbar_items == NULL) {
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (html_notebook), 1);
+	}
 }
 
 static void doc_indent_lcb(GtkWidget *wid,Tbfwin *bfwin) {
@@ -1096,12 +1108,18 @@ void make_main_toolbar(Tbfwin *bfwin) {
 								"", G_CALLBACK(undo_cb), bfwin, -1);
 	bfwin->toolbar_redo = gtk_toolbar_insert_stock (GTK_TOOLBAR (toolbar), GTK_STOCK_REDO, _("Redo"),	
 								"", G_CALLBACK(redo_cb), bfwin, -1);
-	gtk_toolbar_append_space(GTK_TOOLBAR(toolbar));
+	gtk_toolbar_append_space (GTK_TOOLBAR(toolbar));
+#ifdef HAVE_ATLEAST_GTK_2_4
+   gtk_toolbar_insert_stock (GTK_TOOLBAR (toolbar), GTK_STOCK_UNINDENT, _("Shift Left"), 
+                        "", G_CALLBACK (doc_unindent_lcb), bfwin, -1);
+   gtk_toolbar_insert_stock (GTK_TOOLBAR( toolbar), GTK_STOCK_INDENT, _("Shift Right"),
+                        "", G_CALLBACK (doc_indent_lcb), bfwin, -1);
+#else
 	gtk_toolbar_append_item(GTK_TOOLBAR(toolbar), NULL, _("Shift Left"),
-							"", new_pixmap(111), G_CALLBACK(doc_unindent_lcb), bfwin);
+                        "", new_pixmap(111), G_CALLBACK(doc_unindent_lcb), bfwin);
 	gtk_toolbar_append_item(GTK_TOOLBAR(toolbar), NULL, _("Shift Right"),
-							"", new_pixmap(110), G_CALLBACK(doc_indent_lcb), bfwin);
-
+                        "", new_pixmap(110), G_CALLBACK(doc_indent_lcb), bfwin);
+#endif
 /*
 	gtk_toolbar_append_item(GTK_TOOLBAR(toolbar), NULL, _("Print..."), "",
 							new_pixmap(015), G_CALLBACK(file_print_cb), NULL);*/
@@ -1341,15 +1359,15 @@ void gui_create_main(Tbfwin *bfwin, GList *filenames) {
 		bfwin->custom_menu_hb = gtk_handle_box_new();
 		gtk_box_pack_start(GTK_BOX(vbox), bfwin->custom_menu_hb, FALSE, FALSE, 0);
 
-		if ((bfwin->project && bfwin->project->view_main_toolbar) || (!bfwin->project && main_v->props.view_main_toolbar)) {
+		if (bfwin->session->view_main_toolbar) {
 			make_main_toolbar(bfwin);
 			gtk_widget_show(bfwin->main_toolbar_hb);
 		}
-		if ((bfwin->project && bfwin->project->view_html_toolbar) || (!bfwin->project && main_v->props.view_html_toolbar)) {
+		if (bfwin->session->view_html_toolbar) {
 			make_html_toolbar(bfwin);
 			gtk_widget_show(bfwin->html_toolbar_hb);
 		}
-		if ((bfwin->project && bfwin->project->view_custom_menu) || (!bfwin->project && main_v->props.view_custom_menu)) {
+		if (bfwin->session->view_custom_menu) {
 			make_cust_menubar(bfwin,bfwin->custom_menu_hb);
 			gtk_widget_show(bfwin->custom_menu_hb);
 		}
@@ -1380,7 +1398,7 @@ void gui_create_main(Tbfwin *bfwin, GList *filenames) {
 	/* output_box */
 	init_output_box(bfwin, vbox);
 
-	left_panel_show_hide_toggle(bfwin,TRUE, (bfwin->project && bfwin->project->view_left_panel) || (!bfwin->project && main_v->props.view_left_panel), FALSE);
+	left_panel_show_hide_toggle(bfwin,TRUE, (bfwin->session->view_left_panel), FALSE);
 
 	/* finally the statusbar */
 	{
@@ -1417,7 +1435,7 @@ void gui_create_main(Tbfwin *bfwin, GList *filenames) {
 		docs_new_from_files(bfwin,filenames,(bfwin->project != NULL));
 	}
 
-	gtk_notebook_set_page(GTK_NOTEBOOK(bfwin->notebook), 0);
+	gtk_notebook_set_current_page(GTK_NOTEBOOK(bfwin->notebook), 0);
 	gtk_notebook_set_scrollable(GTK_NOTEBOOK(bfwin->notebook), TRUE);
 	/* don't use show_all since some widgets are and should be hidden */
 	gtk_widget_show(bfwin->notebook);
@@ -1444,9 +1462,9 @@ void gui_show_main(Tbfwin *bfwin) {
 	gtk_widget_show(bfwin->main_window);
 	flush_queue();
 	doc_scroll_to_cursor(bfwin->current_document);
-	if ((bfwin->project && bfwin->project->view_left_panel) || (!bfwin->project && main_v->props.view_left_panel)) {
+/*	if ((bfwin->project && bfwin->project->view_left_panel) || (!bfwin->project && main_v->props.view_left_panel)) {
 		filebrowser_scroll_initial(bfwin);
-	}
+	}*/
 }
 /***********************/
 /* statusbar functions */
@@ -1689,19 +1707,19 @@ void gui_toggle_hidewidget_cb(Tbfwin *bfwin,guint action,GtkWidget *widget) {
 	DEBUG_MSG("gui_toggle_hidewidget_cb, action=%d, active=%d\n",action,active);
 	switch (action) {
 	case 1:
-		if (bfwin->project) bfwin->project->view_main_toolbar = active;;
+		bfwin->session->view_main_toolbar = active;
 		gui_set_main_toolbar_visible(bfwin, active, FALSE);
 	break;
 	case 2:
-		if (bfwin->project) bfwin->project->view_html_toolbar = active;
+		bfwin->session->view_html_toolbar = active;
 		gui_set_html_toolbar_visible(bfwin, active, FALSE);
 	break;
 	case 3:
-		if (bfwin->project) bfwin->project->view_custom_menu = active;
+		bfwin->session->view_custom_menu = active;
 		gui_set_custom_menu_visible(bfwin, active, FALSE);
 	break;
 	case 4:
-		if (bfwin->project) bfwin->project->view_left_panel = active;
+		bfwin->session->view_left_panel = active;
 		left_panel_show_hide_toggle(bfwin,FALSE, active, FALSE);
 	break;
 	default:
