@@ -72,6 +72,7 @@ typedef struct {
 	GtkWidget *scriptsrc;
 	GtkWidget *scriptarea;
 	GtkWidget *removeButton;
+	GtkWidget *openNewDoc;
 	Tbfwin *bfwin;
 } TQuickStart;
 
@@ -179,6 +180,7 @@ quickstart_load_metatags(GtkListStore *lstore)
 	const gchar *metaTags[] = {
 		"name=\"generator\" content=\"Bluefish\"",
 		"name=\"author\" content=\"\"",
+		"name=\"date\" content=\"\"",
 		"name=\"copyright\" content=\"\"",
 		"name=\"keywords\" content=\"\"",
 		"name=\"description\" content=\"\"",
@@ -199,11 +201,7 @@ quickstart_load_metatags(GtkListStore *lstore)
 static void
 quickstart_meta_selection_changed(GtkTreeSelection *tselection, TQuickStart *qstart)
 {
-	GtkTreeModel *tmodel;
-	GtkTreeIter iter;
-	
-	tmodel = gtk_tree_view_get_model (GTK_TREE_VIEW (qstart->metaView));
-	if (gtk_tree_selection_get_selected (tselection, &tmodel, &iter)) {
+	if (gtk_tree_selection_count_selected_rows (tselection) > 0) {
 		gtk_widget_set_sensitive (qstart->removeButton, TRUE);	
 	} else {
 		gtk_widget_set_sensitive (qstart->removeButton, FALSE);
@@ -233,14 +231,38 @@ static void
 quickstart_meta_remove_clicked(GtkWidget *widget, TQuickStart *qstart)
 {
 	GtkTreeModel *tmodel;
-	GtkTreeIter iter;
 	GtkTreeSelection *tselection;
+	GtkTreePath *path;
+	GtkTreeRowReference *ref;
+	GList *selectionlist = NULL, *reflist = NULL, *node;
 
+	tmodel = gtk_tree_view_get_model (GTK_TREE_VIEW (qstart->metaView));	
 	tselection = gtk_tree_view_get_selection (GTK_TREE_VIEW (qstart->metaView));
-	tmodel = gtk_tree_view_get_model (GTK_TREE_VIEW (qstart->metaView));
-	if (gtk_tree_selection_get_selected (tselection, &tmodel, &iter)) {
-		gtk_list_store_remove (GTK_LIST_STORE (tmodel), &iter);
+
+	selectionlist = gtk_tree_selection_get_selected_rows (tselection, &tmodel);
+	for (node = selectionlist; node != NULL; node = node->next) {
+		path = node->data;
+		ref = gtk_tree_row_reference_new (tmodel, path);
+		reflist = g_list_append(reflist, ref);
 	}
+	
+	for (node = reflist; node != NULL; node = node->next) {
+		ref = node->data;
+		path = gtk_tree_row_reference_get_path (ref);
+		
+		if (path) {
+			GtkTreeIter iter;
+			
+			if (gtk_tree_model_get_iter (GTK_TREE_MODEL (tmodel), &iter, path)) {
+				gtk_list_store_remove (GTK_LIST_STORE (tmodel), &iter);
+			}
+		}
+	}
+	
+	g_list_foreach (selectionlist, (GFunc) gtk_tree_path_free, NULL);
+	g_list_free (selectionlist);
+	g_list_foreach (reflist, (GFunc) gtk_tree_row_reference_free, NULL);
+	g_list_free (reflist);
 }
 
 static void
@@ -391,12 +413,8 @@ quickstart_response_lcb(GtkDialog *dialog, gint response, TQuickStart *qstart)
 		g_free (stylearea);
 		g_free (scriptsrc);
 		g_free (scriptarea);
-
-		/* I'm wondering if it might be better just to check and see if the 
-		 * current doc is empty or whether it should be an option in the dialog
-		 * to create in a new document.
-		 */		
-		if (!doc_is_empty_non_modified_and_nameless(qstart->bfwin->current_document)) {
+		
+		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (qstart->openNewDoc))) {
 			Tdocument *doc;
 			doc = doc_new(qstart->bfwin, FALSE);
 			switch_to_document_by_pointer(qstart->bfwin, doc);
@@ -440,7 +458,7 @@ quickstart_meta_page_create(TQuickStart *qstart)
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (qstart->metaView), FALSE);
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (qstart->metaView));
 	g_signal_connect (G_OBJECT (selection), "changed", G_CALLBACK (quickstart_meta_selection_changed), qstart);
-	gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
+	gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
 	gtk_container_add (GTK_CONTAINER (scrolwin), qstart->metaView);
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set (renderer, "editable", TRUE, NULL);
@@ -515,7 +533,7 @@ quickstart_style_page_create(TQuickStart *qstart)
 	
 	qstart->stylehref = gtk_combo_box_entry_new_with_model (GTK_TREE_MODEL (history), 0);
 	g_object_unref (history);
-	dialog_mnemonic_label_in_table(_("Hre_f:"), qstart->stylehref, table, 0, 1, 0, 1);
+	dialog_mnemonic_label_in_table(_("HRE_F:"), qstart->stylehref, table, 0, 1, 0, 1);
 	gtk_table_attach (GTK_TABLE (table), qstart->stylehref, 1, 2, 0, 1, GTK_EXPAND|GTK_FILL, GTK_SHRINK, 0, 0);
 	
 	qstart->stylemedia = gtk_entry_new ();
@@ -591,7 +609,7 @@ void
 quickstart_dialog_new(Tbfwin *bfwin)
 {
 	TQuickStart *qstart;
-	GtkWidget *dialog, *table, *frame, *page;
+	GtkWidget *dialog, *table, *frame, *page, *alignment;
 	GtkListStore *headStore;
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
@@ -615,7 +633,7 @@ quickstart_dialog_new(Tbfwin *bfwin)
 													  NULL);	  
 	g_signal_connect (G_OBJECT (dialog), "response", G_CALLBACK (quickstart_response_lcb), qstart);
 
-	table = dialog_table_in_vbox_defaults(5, 3, 6, GTK_DIALOG (dialog)->vbox);
+	table = dialog_table_in_vbox_defaults(4, 3, 6, GTK_DIALOG (dialog)->vbox);
 	
 	qstart->dtd = gtk_combo_box_new_text ();
 	for (i = 0; i < G_N_ELEMENTS (dtds); i++) {
@@ -666,6 +684,13 @@ quickstart_dialog_new(Tbfwin *bfwin)
 	gtk_tree_model_get_iter_first (GTK_TREE_MODEL (headStore), &iter);
 	gtk_tree_selection_select_iter (selection, &iter);
 	
+	qstart->openNewDoc = gtk_check_button_new_with_mnemonic (_("Open in _new document."));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (qstart->openNewDoc), TRUE);
+	alignment = gtk_alignment_new (0, 0.5, 0, 0);
+	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 6, 8, 4, 0);
+	gtk_container_add (GTK_CONTAINER (alignment), qstart->openNewDoc);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), alignment, FALSE, FALSE, 0);
+	
 	gtk_widget_show_all (dialog);
 }
 
