@@ -1,7 +1,7 @@
 /* Bluefish HTML Editor
  * snr2.c - rewrite of search 'n replace functions
  *
- * Copyright (C) 2000-2004 Olivier Sessink
+ * Copyright (C) 2000-2005 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,11 +44,17 @@
 #ifdef HAVE_STRINGS_H
 #include <strings.h>
 #endif /* HAVE_STRINGS_H */
+
 #include <stdio.h>
 #include <string.h>
 #include <sys/types.h>  /* _before_ regex.h for freeBSD */
 #include <regex.h> 				/* regcomp() */
 #include <pcre.h> 	/* pcre_compile */
+
+#ifndef PCRE_UTF8 /* for compatibility with older libpcre's */
+#define PCRE_UTF8 0
+#endif /* PCRE_UTF8 */
+
 #include <gdk/gdkkeysyms.h> /* GDK_Return */
 
 #include "bluefish.h"
@@ -226,7 +232,7 @@ Tsearch_result search_backend(Tbfwin *bfwin, gchar *search_pattern, Tmatch_types
 		int erroffset=0;
 		int ovector[30];
 		gint retval;
-		pcre_c = pcre_compile(search_pattern, (is_case_sens ? PCRE_DOTALL|PCRE_MULTILINE : PCRE_DOTALL|PCRE_CASELESS|PCRE_MULTILINE),&err,&erroffset,NULL);
+		pcre_c = pcre_compile(search_pattern, (is_case_sens ? PCRE_UTF8|PCRE_DOTALL|PCRE_MULTILINE : PCRE_UTF8|PCRE_DOTALL|PCRE_CASELESS|PCRE_MULTILINE),&err,&erroffset,NULL);
 		if (err) {
 			gchar *errstring;
 			errstring = g_strdup_printf(_("Regular expression error: %s at offset %d"), err, erroffset);
@@ -557,6 +563,7 @@ actions, so the first char in buf is actually number offset in the text widget *
 	}
 	DEBUG_MSG("replace_backend, offset=%d, result.start=%d, result.end=%d\n", offset, result.start, result.end);
 	if (result.end > 0) {
+		gchar *tmp;
 		switch (replacetype) {
 		case string:
 			if (matchtype == match_normal) {
@@ -573,11 +580,15 @@ actions, so the first char in buf is actually number offset in the text widget *
 		break;
 		case uppercase:
 			tmpstr = g_strndup(&buf[result.bstart], result.bend - result.bstart);
-			g_strup(tmpstr);
+			tmp = tmpstr;
+			tmpstr = g_utf8_strup(tmpstr, -1);
+			g_free (tmp);
 		break;
 		case lowercase:
 			tmpstr = g_strndup(&buf[result.bstart], result.bend - result.bstart);
-			g_strdown(tmpstr);
+			tmp = tmpstr;
+			tmpstr = g_utf8_strdown(tmpstr, -1);
+			g_free (tmp);
 		break;
 		}
 		DEBUG_MSG("replace_backend, len=%d, offset=%d, start=%d, end=%d, document=%p, tmpstr='%s'\n", result.end - result.start, offset, result.start + offset, result.end + offset, doc,tmpstr);
@@ -776,11 +787,17 @@ static void replace_prompt_dialog_ok_lcb(GtkWidget *widget, Tbfwin *bfwin) {
 			tmpstr = reg_replace(tmpstr, 0, LASTSNR2(bfwin->snr2)->result, bfwin->current_document, LASTSNR2(bfwin->snr2)->unescape);
 			
 		} else if (LASTSNR2(bfwin->snr2)->replacetype_option==uppercase) {
+			gchar *tmp;
 			tmpstr = doc_get_chars(bfwin->current_document, LASTSNR2(bfwin->snr2)->result.start ,LASTSNR2(bfwin->snr2)->result.end);
-			g_strup(tmpstr);
+			tmp = tmpstr;
+			tmpstr = g_utf8_strup(tmpstr, -1);
+			g_free (tmp);
 		} else {
+			gchar *tmp;
 			tmpstr = doc_get_chars(bfwin->current_document, LASTSNR2(bfwin->snr2)->result.start ,LASTSNR2(bfwin->snr2)->result.end);
-			g_strdown(tmpstr);
+			tmp = tmpstr;
+			tmpstr = g_utf8_strdown(tmpstr, -1);
+			g_free (tmp);
 		}
 		/* avoid new highlighting at this stage, so call the backend directly instead of the frontend function
 		this because the highlighting interferes with the selection
@@ -1324,7 +1341,9 @@ static gboolean search_entry_key_press_event_lcb(GtkWidget *widget,GdkEventKey *
 static void snr2dialog(Tbfwin *bfwin, gint is_replace, gint is_new_search) {
 	Tsnr2_win *snr2win;
 	GtkWidget *vbox, *hbox, *button, *table;
-	gchar *tmptext;
+	const gchar *tmptext;
+   gchar *buffer;
+   GtkTextIter start, end;
 
 	snr2win = g_malloc(sizeof(Tsnr2_win));
 	snr2win->bfwin = bfwin;
@@ -1364,8 +1383,15 @@ static void snr2dialog(Tbfwin *bfwin, gint is_replace, gint is_new_search) {
 	gtk_label_set_justify (GTK_LABEL (snr2win->search_label), GTK_JUSTIFY_LEFT);
 	gtk_misc_set_alignment (GTK_MISC (snr2win->search_label), 0, 0.5);
 	/*snr2win->search_scrollbox = textview_buffer_in_scrolwin(&snr2win->search_entry, 300, 50, LASTSNR2(bfwin->snr2)->search_pattern, GTK_WRAP_NONE);*/
-	
-	snr2win->search_combo = combo_with_popdown("", bfwin->session->searchlist, TRUE);
+   gtk_text_buffer_get_selection_bounds(bfwin->current_document->buffer, &start, &end);
+   buffer = gtk_text_buffer_get_text(bfwin->current_document->buffer, &start, &end, FALSE);
+   if (strchr(buffer,'\n')!=NULL) {
+      /* a newline in the selection, we probably don't want this string as search string */
+      g_free(buffer);
+      buffer = NULL;
+   }
+   snr2win->search_combo = combo_with_popdown(buffer ? buffer : "", bfwin->session->searchlist, TRUE);
+   if (buffer) g_free(buffer);
 	gtk_table_attach (GTK_TABLE (table), snr2win->search_combo, 1, 2, 0, 1,
 					(GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (GTK_FILL), 0, 0);
 	/*g_signal_connect(G_OBJECT(snr2win->search_entry), "key_press_event", G_CALLBACK(search_entry_key_press_event_lcb), snr2win);*/
@@ -1445,7 +1471,7 @@ static void snr2dialog(Tbfwin *bfwin, gint is_replace, gint is_new_search) {
 		snr2win->prompt_before_replace = boxed_checkbut_with_value(_("Prompt _before replace"), LASTSNR2(bfwin->snr2)->prompt_before_replace, vbox);
 		snr2win->replace_once = boxed_checkbut_with_value(_("Replace o_nce"), LASTSNR2(bfwin->snr2)->replace_once, vbox);
 	} else {
-		snr2win->bookmark_results = boxed_checkbut_with_value(_("Bookmark results"), LASTSNR2(bfwin->snr2)->bookmark_results, vbox);
+		snr2win->bookmark_results = boxed_checkbut_with_value(_("_Bookmark results"), LASTSNR2(bfwin->snr2)->bookmark_results, vbox);
 	}
 
 	hbox = gtk_hseparator_new ();
